Template3_10

Struct Template3_10 

pub struct Template3_10 {
Show 13 fields pub earth_shape: EarthShape, pub ni: u32, pub nj: u32, pub first_point_lat: i32, pub first_point_lon: u32, pub resolution_and_component_flags: ResolutionAndComponentFlags, pub lad: i32, pub last_point_lat: i32, pub last_point_lon: u32, pub scanning_mode: ScanningMode, pub orientation: u32, pub di: u32, pub dj: u32,
}
Grid definition template 3.10 - Mercator.

Examples

use std::io::{BufReader, Read};

use grib::{
    TryFromSlice,
    def::grib2::template::{Template3_10, param_set},
};

fn main() -> Result<(), Box<dyn std::error::Error>> {
    let mut buf = Vec::new();

    let f = std::fs::File::open("testdata/ds.wwa.bin.xz")?;
    let f = BufReader::new(f);
    let mut f = xz2::bufread::XzDecoder::new(f);
    f.read_to_end(&mut buf)?;

    let mut pos = 0xa6;
    let actual = Template3_10::try_from_slice(&buf, &mut pos)?;
    let expected = Template3_10 {
        earth_shape: param_set::EarthShape {
            shape: 1,
            spherical_earth_radius: param_set::ScaledValue {
                scale_factor: 0,
                scaled_value: 6371200,
            },
            major_axis: param_set::ScaledValue {
                scale_factor: 0,
                scaled_value: 0,
            },
            minor_axis: param_set::ScaledValue {
                scale_factor: 0,
                scaled_value: 0,
            },
        },
        ni: 2517,
        nj: 1793,
        first_point_lat: -30419200,
        first_point_lon: 129906005,
        resolution_and_component_flags: param_set::ResolutionAndComponentFlags(0b00000000),
        lad: 20000000,
        last_point_lat: 80010000,
        last_point_lon: 10710000,
        scanning_mode: param_set::ScanningMode(0b01010000),
        orientation: 0,
        di: 10000000,
        dj: 10000000,
    };
    assert_eq!(actual, expected);

    Ok(())
}

Fields

earth_shape: EarthShapeni: u32

Ni - number of points along a parallel.

nj: u32

Nj - number of points along a meridian.

first_point_lat: i32

La1 - latitude of first grid point.

first_point_lon: u32

Lo1 - longitude of first grid point.

resolution_and_component_flags: ResolutionAndComponentFlagslad: i32

LaD - Latitude(s) at which the Mercator projection intersects the Earth (Latitude(s) where Di and Dj are specified).

last_point_lat: i32

La2 - latitude of last grid point.

last_point_lon: u32

Lo2 - longitude of last grid point.

scanning_mode: ScanningModeorientation: u32

Orientation of the grid, angle between i direction on the map and the equator (see Note 1).

di: u32

Di - longitudinal direction grid length (see Note 2).

dj: u32

Dj - latitudinal direction grid length (see Note 2).