pub struct Template3_41 {
pub earth: EarthShape,
pub gaussian: GaussianGrid,
pub rotation: Rotation,
}Expand description
Grid definition template 3.41 - rotated Gaussian latitude/longitude.
Fields
earth: EarthShapegaussian: GaussianGridrotation: RotationTrait Implementations
Sourceimpl Clone for Template3_41
impl Clone for Template3_41
Sourcefn clone(&self) -> Template3_41
fn clone(&self) -> Template3_41
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Template3_41
impl Debug for Template3_41
Sourceimpl Dump for Template3_41
impl Dump for Template3_41
Sourceimpl GridPointIndex for Template3_41
impl GridPointIndex for Template3_41
Sourcefn grid_shape(&self) -> (usize, usize)
fn grid_shape(&self) -> (usize, usize)
Returns the shape of the grid, i.e. a tuple of the number of grids in
the i and j directions.
Sourcefn scanning_mode(&self) -> &ScanningMode
fn scanning_mode(&self) -> &ScanningMode
Returns
ScanningMode used for the iteration.Sourceimpl GridShortName for Template3_41
impl GridShortName for Template3_41
Sourcefn short_name(&self) -> &'static str
fn short_name(&self) -> &'static str
Returns the grid type. Read more
Sourceimpl LatLons for Template3_41
impl LatLons for Template3_41
type Iter<'a> = Unrotate<RegularGridIterator> where Self: 'a
Sourcefn latlons_unchecked<'a>(&'a self) -> Result<Self::Iter<'a>, GribError>
fn latlons_unchecked<'a>(&'a self) -> Result<Self::Iter<'a>, GribError>
Computes and returns an iterator over latitudes and longitudes of grid
points in degrees. Unlike the return values from
LatLons::latlons,
the longitude values from thie method do not necessarily fall within
the range [-180°, 180°].Sourceimpl PartialEq for Template3_41
impl PartialEq for Template3_41
impl StructuralPartialEq for Template3_41
Sourceimpl TryFromSlice for Template3_41
impl TryFromSlice for Template3_41
Sourceimpl WriteToBuffer for Template3_41
impl WriteToBuffer for Template3_41