pub struct Template4_2 {
pub param: ProductParam,
pub generating_process: GeneratingProcess,
pub forecast_time: ForecastTime,
pub horizontal: Horizontal,
pub derived_forecast: DerivedForecast,
}Expand description
Product definition template 4.2 - Derived forecast based on all ensemble members at a horizontal level or in a horizontal layer at a point in time.
Fields
param: ProductParamgenerating_process: GeneratingProcessforecast_time: ForecastTimehorizontal: Horizontalderived_forecast: DerivedForecastTrait Implementations
Sourceimpl Clone for Template4_2
impl Clone for Template4_2
Sourcefn clone(&self) -> Template4_2
fn clone(&self) -> Template4_2
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Template4_2
impl Debug for Template4_2
Sourceimpl Dump for Template4_2
impl Dump for Template4_2
Sourceimpl PartialEq for Template4_2
impl PartialEq for Template4_2
impl StructuralPartialEq for Template4_2
Sourceimpl TryFromSlice for Template4_2
impl TryFromSlice for Template4_2
Sourceimpl WriteToBuffer for Template4_2
impl WriteToBuffer for Template4_2